import { RevertableEvent } from "@skeldjs/events";
import { RepairSystemMessage } from "@skeldjs/protocol";
import { RoomEvent } from "../RoomEvent";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
import { MovingPlatformSide, MovingPlatformSystem } from "../../systems";
import { ProtocolEvent } from "../ProtocolEvent";
import { MovingPlatformEvent } from "./MovingPlatformEvent";
/**
 * Emitted when the player on a moving platform is updated. This is also when
 * the moving platform moves left or right.
 */
export declare class MovingPlatformPlayerUpdateEvent<RoomType extends Hostable = Hostable> extends RevertableEvent implements RoomEvent, MovingPlatformEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly movingplatform: MovingPlatformSystem<RoomType>;
    readonly message: RepairSystemMessage | undefined;
    /**
     * The player on the moving platform, if any.
     */
    readonly player: PlayerData<RoomType> | undefined;
    /**
     * The direction that the moving platform is moving in.
     */
    readonly side: MovingPlatformSide;
    static eventName: "movingplatform.updateplayer";
    eventName: "movingplatform.updateplayer";
    private _alteredPlayer;
    private _alteredSide;
    constructor(room: RoomType, movingplatform: MovingPlatformSystem<RoomType>, message: RepairSystemMessage | undefined, 
    /**
     * The player on the moving platform, if any.
     */
    player: PlayerData<RoomType> | undefined, 
    /**
     * The direction that the moving platform is moving in.
     */
    side: MovingPlatformSide);
    /**
     * The altered player that will be on the moving platform, if changed.
     */
    get alteredPlayer(): PlayerData<RoomType> | undefined;
    /**
     * The altered direction that the moving platfomr will move in, if changed.
     */
    get alteredSide(): MovingPlatformSide;
    /**
     * Change the player that is on the moving platform.
     * @param player The player to get onto the moving platform.
     */
    setPlayer(player: PlayerData<RoomType> | undefined): void;
    /**
     * Change the direction that the moving platform is moving in.
     * @param side The direction for the moving platform to move.
     */
    setSide(side: MovingPlatformSide): void;
}
