import { BasicEvent } from "@skeldjs/events";
import { SetNameMessage } from "@skeldjs/protocol";
import { RoomEvent } from "../RoomEvent";
import { ProtocolEvent } from "../ProtocolEvent";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
import { PlayerEvent } from "./PlayerEvent";
/**
 * Emitted when a player has their player name updated.
 */
export declare class PlayerSetNameEvent<RoomType extends Hostable = Hostable> extends BasicEvent implements RoomEvent, PlayerEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly player: PlayerData<RoomType>;
    readonly message: SetNameMessage | undefined;
    /**
     * The name that the player had before.
     */
    readonly oldName: string;
    /**
     * The new name that the player has.
     */
    readonly newName: string;
    static eventName: "player.setname";
    eventName: "player.setname";
    private _alteredName;
    constructor(room: RoomType, player: PlayerData<RoomType>, message: SetNameMessage | undefined, 
    /**
     * The name that the player had before.
     */
    oldName: string, 
    /**
     * The new name that the player has.
     */
    newName: string);
    /**
     * The altered name that the player will have set instead, if changed.
     */
    get alteredName(): string;
    /**
     * Revert the player's name back to their old name.
     */
    revert(): void;
    /**
     * Change the name that the player had set.
     * @param name The name to set.
     */
    setName(name: string): void;
}
