import { HazelReader, HazelWriter } from "@skeldjs/util";
import { SystemType } from "@skeldjs/constant";
import { RepairSystemMessage } from "@skeldjs/protocol";
import { ExtractEventTypes } from "@skeldjs/events";
import { InnerShipStatus } from "../objects";
import { SystemStatus } from "./SystemStatus";
import { PlayerData } from "../PlayerData";
import { SystemStatusEvents } from "./events";
import { Hostable } from "../Hostable";
export interface HudOverrideSystemData {
    sabotaged: boolean;
}
export declare type HudOverrideSystemEvents<RoomType extends Hostable = Hostable> = SystemStatusEvents<RoomType> & ExtractEventTypes<[]>;
/**
 * Represents a system responsible for handling communication sabotages on The Skeld and Polus.
 *
 * See {@link HudOverrideSystemEvents} for events to listen to.
 */
export declare class HudOverrideSystem<RoomType extends Hostable = Hostable> extends SystemStatus<HudOverrideSystemData, HudOverrideSystemEvents, RoomType> implements HudOverrideSystemData {
    private _sabotaged;
    /**
     * Whether or not communications is sabotaged.
     */
    get sabotaged(): boolean;
    constructor(ship: InnerShipStatus<RoomType>, systemType: SystemType, data?: HazelReader | HudOverrideSystemData);
    patch(data: HudOverrideSystemData): void;
    Deserialize(reader: HazelReader, spawn: boolean): void;
    Serialize(writer: HazelWriter, spawn: boolean): void;
    HandleSabotage(player: PlayerData | undefined, rpc: RepairSystemMessage | undefined): Promise<void>;
    _repair(player: PlayerData | undefined, rpc: RepairSystemMessage | undefined): Promise<void>;
    repair(): Promise<void>;
    HandleRepair(player: PlayerData<RoomType> | undefined, amount: number, rpc: RepairSystemMessage | undefined): Promise<void>;
}
