"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SabotageSystem = void 0;
const SystemStatus_1 = require("./SystemStatus");
/**
 * Represents a system responsible for handling system sabotages.
 *
 * See {@link SabotageSystemEvents} for events to listen to.
 */
class SabotageSystem extends SystemStatus_1.SystemStatus {
    constructor(ship, systemType, data) {
        var _a;
        super(ship, systemType, data);
        (_a = this.cooldown) !== null && _a !== void 0 ? _a : (this.cooldown = 10000);
    }
    /**
     * Check whether any systems are currently sabotaged.
     */
    get anySabotaged() {
        return Object.values(this.ship.systems).some(system => system === null || system === void 0 ? void 0 : system.sabotaged);
    }
    /* eslint-disable-next-line @typescript-eslint/no-unused-vars */
    Deserialize(reader, spawn) {
        this.cooldown = reader.float();
    }
    /* eslint-disable-next-line @typescript-eslint/no-unused-vars */
    Serialize(writer, spawn) {
        writer.float(this.cooldown);
    }
    async HandleRepair(player, amount, rpc) {
        const system = this.ship.systems.get(amount);
        if (system) {
            await system.HandleSabotage(player, rpc);
            this.cooldown = 30;
            this.dirty = true;
        }
    }
    Detoriorate(delta) {
        if (this.cooldown > 0 && !this.anySabotaged) {
            this.cooldown -= delta;
            if (this.cooldown <= 0) {
                this.dirty = true;
            }
        }
    }
}
exports.SabotageSystem = SabotageSystem;
//# sourceMappingURL=SabotageSystem.js.map